Package: MDTS
Title: Detection of de novo deletion in targeted sequencing trios
Version: 1.30.0
Authors@R: person("Jack M..", "Fu", email = "jmfu@jhsph.edu", role = c("aut", "cre"))
Description: A package for the detection of de novo copy number deletions in targeted sequencing of trios with high sensitivity and positive predictive value.
Depends: R (>= 3.5.0)
Imports: GenomicAlignments, GenomicRanges, IRanges, Biostrings,
        DNAcopy, Rsamtools, parallel, stringr
Suggests: testthat, knitr
VignetteBuilder: knitr
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 6.0.1
biocViews: StatisticalMethod, Technology, Sequencing,
        TargetedResequencing, Coverage, DataImport
git_url: https://git.bioconductor.org/packages/MDTS
git_branch: RELEASE_3_22
git_last_commit: 2e2c502
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 04:53:55 UTC; biocbuild
Author: Jack M.. Fu [aut, cre]
Maintainer: Jack M.. Fu <jmfu@jhsph.edu>
