# Generated by roxygen2: do not edit by hand

export(calcBins)
export(calcCounts)
export(calcMD)
export(denovoDeletions)
export(getMetaData)
export(normalizeCounts)
export(segmentMD)
export(visualizeDeletion)
import(GenomicAlignments)
import(GenomicRanges)
import(parallel)
importFrom(Biostrings,getSeq)
importFrom(DNAcopy,CNA)
importFrom(DNAcopy,segment)
importFrom(GenomicAlignments,coverage)
importFrom(GenomicAlignments,readGAlignments)
importFrom(IRanges,IRanges)
importFrom(Rsamtools,ScanBamParam)
importFrom(Rsamtools,scanBamFlag)
