## Overview

MDTS provides the necessary infrastructure to take raw bam files of targeted sequencing trios to produce de novo deletion calls of high sensitivity and low false positives. Our method benefits tremendously from pooling information from across many trios to determine regions of interest, normalize read-depth, and to filter candidate deletion signals.

To install please use `install_github('jmf47/MDTS', ref="R-3.4", build_vignettes=TRUE)`.

To view the vignette after installing MDTS use `vignette("mdts", package="MDTS")`.
