#' The MDTS package for Detection of Denovo Deletions from Targeted Sequencing 
#' Data Using Minimum-Distance
#'
#' @name MDTS-package
#' @aliases MDTS
#' @docType package
#' @import parallel
#' @import GenomicRanges
#' @import GenomicAlignments
NULL
